@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.14
+# Version   : 0.1.17
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -418,7 +418,7 @@ class AFM:
 
         self.approach_raw = np.zeros([self.samps_line, len(self.filelist)])
         self.retract_raw = np.zeros([self.samps_line, len(self.filelist)])
-        self.z_position_raw = np.zeros([self.samps_line, len(self.filelist)])
+        self.z_position_raw = np.zeros([self.samps_line * 2 , len(self.filelist)])
 
         for filename in self.filelist:
 
@@ -496,11 +496,10 @@ class AFM:
 
             baseline_start = int(len(_z) * start_pos)
             baseline_end = int(len(_z) * end_pos)
-            approach_baseline_region = np.arange(baseline_start,baseline_end)
-            retract_baseline_region = np.arange(baseline_start + self.samps_line, baseline_end + self.samps_line)
+            baseline_region = np.arange(baseline_start,baseline_end)
 
-            _approach_region = _approach[approach_baseline_region]
-            _retract_region = _retract[retract_baseline_region]
+            _approach_region = _approach[baseline_region]
+            _retract_region = _retract[baseline_region]
             _z_region = _z[baseline_region]
 
             _approach_mean = np.mean(_approach_region)
